SelectableTextSpanParser class

Constructors

SelectableTextSpanParser()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

export(TextSpan textSpan) → Map<String, dynamic>
exportChildren(TextSpan textSpan) → List<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(Map<String, dynamic> map, ClickListener? listener) → TextSpan
parseChildren(TextSpan textSpan, List childrenSpan, ClickListener? listener) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited