DropCapText class

Inheritance

Constructors

DropCapText({Key? key, required String data, bool? selectable, DropCapMode? mode, TextStyle? style, TextStyle? dropCapStyle, TextAlign textAlign = TextAlign.start, DropCap? dropCap, EdgeInsets? dropCapPadding = EdgeInsets.zero, Offset indentation = Offset.zero, int? dropCapChars = 1, bool? forceNoDescent = false, bool? parseInlineMarkdown = false, TextDirection textDirection = TextDirection.ltr, TextOverflow? overflow, int? maxLines, DropCapPosition? dropCapPosition})

Properties

data → String
final
dropCap → DropCap?
final
dropCapChars → int?
final
dropCapPadding → EdgeInsets?
final
dropCapPosition → DropCapPosition?
final
dropCapStyle → TextStyle?
final
forceNoDescent → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
indentation → Offset
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines → int?
final
mode → DropCapMode?
final
overflow → TextOverflow?
final
parseInlineMarkdown → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectable → bool?
final
style → TextStyle?
final
textAlign → TextAlign
final
textDirection → TextDirection
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited