GridViewParams class

Constructors

GridViewParams({int? crossAxisCount, Axis? scrollDirection, bool? reverse, bool? shrinkWrap, double? cacheExtent, EdgeInsetsGeometry? padding, double? mainAxisSpacing, double? crossAxisSpacing, double? childAspectRatio, List<Widget?>? children, int? pageSize, String? loadMoreUrl, bool? isDemo})

Properties

cacheExtent ↔ double?
getter/setter pair
childAspectRatio ↔ double?
getter/setter pair
children ↔ List<Widget?>?
getter/setter pair
crossAxisCount ↔ int?
getter/setter pair
crossAxisSpacing ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDemo ↔ bool?
getter/setter pair
loadMoreUrl ↔ String?
getter/setter pair
mainAxisSpacing ↔ double?
getter/setter pair
padding ↔ EdgeInsetsGeometry?
getter/setter pair
pageSize ↔ int?
getter/setter pair
reverse ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection ↔ Axis?
getter/setter pair
shrinkWrap ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited